Class: Aws::ComputeOptimizerAutomation::Types::DisassociateAccountsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-computeoptimizerautomation/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#account_idsArray<String>

The IDs of the member accounts to disassociate.

Returns:

  • (Array<String>)


649
650
651
652
653
654
# File 'lib/aws-sdk-computeoptimizerautomation/types.rb', line 649

class DisassociateAccountsRequest < Struct.new(
  :account_ids,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#client_tokenString

A unique identifier to ensure idempotency of the request.

**A suitable default value is auto-generated.** You should normally not need to pass this option.

Returns:

  • (String)


649
650
651
652
653
654
# File 'lib/aws-sdk-computeoptimizerautomation/types.rb', line 649

class DisassociateAccountsRequest < Struct.new(
  :account_ids,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end