Class: Aws::ComputeOptimizerAutomation::Types::StartAutomationEventRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-computeoptimizerautomation/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#client_tokenString

A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. Must be 1-64 characters long and contain only alphanumeric characters, underscores, and hyphens.

**A suitable default value is auto-generated.** You should normally not need to pass this option.

Returns:

  • (String)


2104
2105
2106
2107
2108
2109
# File 'lib/aws-sdk-computeoptimizerautomation/types.rb', line 2104

class StartAutomationEventRequest < Struct.new(
  :recommended_action_id,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

The ID of the recommended action to automate.

Returns:

  • (String)


2104
2105
2106
2107
2108
2109
# File 'lib/aws-sdk-computeoptimizerautomation/types.rb', line 2104

class StartAutomationEventRequest < Struct.new(
  :recommended_action_id,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end