Class: Aws::ComputeOptimizerAutomation::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::ComputeOptimizerAutomation::Client
- Includes:
- Aws::ClientStubs
- Defined in:
- lib/aws-sdk-computeoptimizerautomation/client.rb
Overview
An API client for ComputeOptimizerAutomation. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::ComputeOptimizerAutomation::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#associate_accounts(params = {}) ⇒ Types::AssociateAccountsResponse
Associates one or more member accounts with your organization’s management account, enabling centralized implementation of optimization actions across those accounts.
-
#create_automation_rule(params = {}) ⇒ Types::CreateAutomationRuleResponse
Creates a new automation rule to apply recommended actions to resources based on specified criteria.
-
#delete_automation_rule(params = {}) ⇒ Struct
Deletes an existing automation rule.
-
#disassociate_accounts(params = {}) ⇒ Types::DisassociateAccountsResponse
Disassociates member accounts from your organization’s management account, removing centralized automation capabilities.
-
#get_automation_event(params = {}) ⇒ Types::GetAutomationEventResponse
Retrieves details about a specific automation event.
-
#get_automation_rule(params = {}) ⇒ Types::GetAutomationRuleResponse
Retrieves details about a specific automation rule.
-
#get_enrollment_configuration(params = {}) ⇒ Types::GetEnrollmentConfigurationResponse
Retrieves the current enrollment configuration for Compute Optimizer Automation.
-
#list_accounts(params = {}) ⇒ Types::ListAccountsResponse
Lists the accounts in your organization that are enrolled in Compute Optimizer and whether they have enabled Automation.
-
#list_automation_event_steps(params = {}) ⇒ Types::ListAutomationEventStepsResponse
Lists the steps for a specific automation event.
-
#list_automation_event_summaries(params = {}) ⇒ Types::ListAutomationEventSummariesResponse
Provides a summary of automation events based on specified filters.
-
#list_automation_events(params = {}) ⇒ Types::ListAutomationEventsResponse
Lists automation events based on specified filters.
-
#list_automation_rule_preview(params = {}) ⇒ Types::ListAutomationRulePreviewResponse
Returns a preview of the recommended actions that match your Automation rule’s configuration and criteria.
-
#list_automation_rule_preview_summaries(params = {}) ⇒ Types::ListAutomationRulePreviewSummariesResponse
Returns a summary of the recommended actions that match your rule preview configuration and criteria.
-
#list_automation_rules(params = {}) ⇒ Types::ListAutomationRulesResponse
Lists the automation rules that match specified filters.
-
#list_recommended_action_summaries(params = {}) ⇒ Types::ListRecommendedActionSummariesResponse
Provides a summary of recommended actions based on specified filters.
-
#list_recommended_actions(params = {}) ⇒ Types::ListRecommendedActionsResponse
Lists the recommended actions based that match specified filters.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists the tags for a specified resource.
-
#rollback_automation_event(params = {}) ⇒ Types::RollbackAutomationEventResponse
Initiates a rollback for a completed automation event.
-
#start_automation_event(params = {}) ⇒ Types::StartAutomationEventResponse
Initiates a one-time, on-demand automation for the specified recommended action.
-
#tag_resource(params = {}) ⇒ Struct
Adds tags to the specified resource.
-
#untag_resource(params = {}) ⇒ Struct
Removes tags from the specified resource.
-
#update_automation_rule(params = {}) ⇒ Types::UpdateAutomationRuleResponse
Updates an existing automation rule.
-
#update_enrollment_configuration(params = {}) ⇒ Types::UpdateEnrollmentConfigurationResponse
Updates your account’s Compute Optimizer Automation enrollment configuration.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
480 481 482 |
# File 'lib/aws-sdk-computeoptimizerautomation/client.rb', line 480 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2230 2231 2232 |
# File 'lib/aws-sdk-computeoptimizerautomation/client.rb', line 2230 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2233 2234 2235 |
# File 'lib/aws-sdk-computeoptimizerautomation/client.rb', line 2233 def errors_module Errors end |
Instance Method Details
#associate_accounts(params = {}) ⇒ Types::AssociateAccountsResponse
Associates one or more member accounts with your organization’s management account, enabling centralized implementation of optimization actions across those accounts. Once associated, the management account (or a delegated administrator) can apply recommended actions to the member account. When you associate a member account, its organization rule mode is automatically set to “Any allowed,” which permits the management account to create Automation rules that automatically apply actions to that account. If the member account has not previously enabled the Automation feature, the association process automatically enables it.
<note markdown=“1”> Only the management account or a delegated administrator can perform this action.
</note>
536 537 538 539 |
# File 'lib/aws-sdk-computeoptimizerautomation/client.rb', line 536 def associate_accounts(params = {}, = {}) req = build_request(:associate_accounts, params) req.send_request() end |
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2203 2204 2205 2206 2207 2208 2209 2210 2211 2212 2213 2214 2215 2216 2217 2218 2219 |
# File 'lib/aws-sdk-computeoptimizerautomation/client.rb', line 2203 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::ComputeOptimizerAutomation') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-computeoptimizerautomation' context[:gem_version] = '1.5.0' Seahorse::Client::Request.new(handlers, context) end |
#create_automation_rule(params = {}) ⇒ Types::CreateAutomationRuleResponse
Creates a new automation rule to apply recommended actions to resources based on specified criteria.
749 750 751 752 |
# File 'lib/aws-sdk-computeoptimizerautomation/client.rb', line 749 def create_automation_rule(params = {}, = {}) req = build_request(:create_automation_rule, params) req.send_request() end |
#delete_automation_rule(params = {}) ⇒ Struct
Deletes an existing automation rule.
782 783 784 785 |
# File 'lib/aws-sdk-computeoptimizerautomation/client.rb', line 782 def delete_automation_rule(params = {}, = {}) req = build_request(:delete_automation_rule, params) req.send_request() end |
#disassociate_accounts(params = {}) ⇒ Types::DisassociateAccountsResponse
Disassociates member accounts from your organization’s management account, removing centralized automation capabilities. Once disassociated, organization rules no longer apply to the member account, and the management account (or delegated administrator) cannot create Automation rules for that account.
<note markdown=“1”> Only the management account or a delegated administrator can perform this action.
</note>
830 831 832 833 |
# File 'lib/aws-sdk-computeoptimizerautomation/client.rb', line 830 def disassociate_accounts(params = {}, = {}) req = build_request(:disassociate_accounts, params) req.send_request() end |
#get_automation_event(params = {}) ⇒ Types::GetAutomationEventResponse
Retrieves details about a specific automation event.
889 890 891 892 |
# File 'lib/aws-sdk-computeoptimizerautomation/client.rb', line 889 def get_automation_event(params = {}, = {}) req = build_request(:get_automation_event, params) req.send_request() end |
#get_automation_rule(params = {}) ⇒ Types::GetAutomationRuleResponse
Retrieves details about a specific automation rule.
986 987 988 989 |
# File 'lib/aws-sdk-computeoptimizerautomation/client.rb', line 986 def get_automation_rule(params = {}, = {}) req = build_request(:get_automation_rule, params) req.send_request() end |
#get_enrollment_configuration(params = {}) ⇒ Types::GetEnrollmentConfigurationResponse
Retrieves the current enrollment configuration for Compute Optimizer Automation.
1012 1013 1014 1015 |
# File 'lib/aws-sdk-computeoptimizerautomation/client.rb', line 1012 def get_enrollment_configuration(params = {}, = {}) req = build_request(:get_enrollment_configuration, params) req.send_request() end |
#list_accounts(params = {}) ⇒ Types::ListAccountsResponse
Lists the accounts in your organization that are enrolled in Compute Optimizer and whether they have enabled Automation.
<note markdown=“1”> Only the management account or a delegated administrator can perform this action.
</note>
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1059 1060 1061 1062 |
# File 'lib/aws-sdk-computeoptimizerautomation/client.rb', line 1059 def list_accounts(params = {}, = {}) req = build_request(:list_accounts, params) req.send_request() end |
#list_automation_event_steps(params = {}) ⇒ Types::ListAutomationEventStepsResponse
Lists the steps for a specific automation event. You can only list steps for events created within the past year.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1113 1114 1115 1116 |
# File 'lib/aws-sdk-computeoptimizerautomation/client.rb', line 1113 def list_automation_event_steps(params = {}, = {}) req = build_request(:list_automation_event_steps, params) req.send_request() end |
#list_automation_event_summaries(params = {}) ⇒ Types::ListAutomationEventSummariesResponse
Provides a summary of automation events based on specified filters. Only events created within the past year will be included in the summary.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1183 1184 1185 1186 |
# File 'lib/aws-sdk-computeoptimizerautomation/client.rb', line 1183 def list_automation_event_summaries(params = {}, = {}) req = build_request(:list_automation_event_summaries, params) req.send_request() end |
#list_automation_events(params = {}) ⇒ Types::ListAutomationEventsResponse
Lists automation events based on specified filters. You can retrieve events that were created within the past year.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1255 1256 1257 1258 |
# File 'lib/aws-sdk-computeoptimizerautomation/client.rb', line 1255 def list_automation_events(params = {}, = {}) req = build_request(:list_automation_events, params) req.send_request() end |
#list_automation_rule_preview(params = {}) ⇒ Types::ListAutomationRulePreviewResponse
Returns a preview of the recommended actions that match your Automation rule’s configuration and criteria.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1396 1397 1398 1399 |
# File 'lib/aws-sdk-computeoptimizerautomation/client.rb', line 1396 def list_automation_rule_preview(params = {}, = {}) req = build_request(:list_automation_rule_preview, params) req.send_request() end |
#list_automation_rule_preview_summaries(params = {}) ⇒ Types::ListAutomationRulePreviewSummariesResponse
Returns a summary of the recommended actions that match your rule preview configuration and criteria.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1513 1514 1515 1516 |
# File 'lib/aws-sdk-computeoptimizerautomation/client.rb', line 1513 def list_automation_rule_preview_summaries(params = {}, = {}) req = build_request(:list_automation_rule_preview_summaries, params) req.send_request() end |
#list_automation_rules(params = {}) ⇒ Types::ListAutomationRulesResponse
Lists the automation rules that match specified filters.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1579 1580 1581 1582 |
# File 'lib/aws-sdk-computeoptimizerautomation/client.rb', line 1579 def list_automation_rules(params = {}, = {}) req = build_request(:list_automation_rules, params) req.send_request() end |
#list_recommended_action_summaries(params = {}) ⇒ Types::ListRecommendedActionSummariesResponse
Provides a summary of recommended actions based on specified filters.
<note markdown=“1”> Management accounts and delegated administrators can retrieve recommended actions that include associated member accounts. You can associate a member account using ‘AssociateAccounts`.
</note>
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1640 1641 1642 1643 |
# File 'lib/aws-sdk-computeoptimizerautomation/client.rb', line 1640 def list_recommended_action_summaries(params = {}, = {}) req = build_request(:list_recommended_action_summaries, params) req.send_request() end |
#list_recommended_actions(params = {}) ⇒ Types::ListRecommendedActionsResponse
Lists the recommended actions based that match specified filters.
<note markdown=“1”> Management accounts and delegated administrators can retrieve recommended actions that include associated member accounts. You can associate a member account using ‘AssociateAccounts`.
</note>
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1719 1720 1721 1722 |
# File 'lib/aws-sdk-computeoptimizerautomation/client.rb', line 1719 def list_recommended_actions(params = {}, = {}) req = build_request(:list_recommended_actions, params) req.send_request() end |
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists the tags for a specified resource.
1749 1750 1751 1752 |
# File 'lib/aws-sdk-computeoptimizerautomation/client.rb', line 1749 def (params = {}, = {}) req = build_request(:list_tags_for_resource, params) req.send_request() end |
#rollback_automation_event(params = {}) ⇒ Types::RollbackAutomationEventResponse
Initiates a rollback for a completed automation event.
<note markdown=“1”> Management accounts and delegated administrators can only initiate a rollback for events belonging to associated member accounts. You can associate a member account using ‘AssociateAccounts`.
</note>
1794 1795 1796 1797 |
# File 'lib/aws-sdk-computeoptimizerautomation/client.rb', line 1794 def rollback_automation_event(params = {}, = {}) req = build_request(:rollback_automation_event, params) req.send_request() end |
#start_automation_event(params = {}) ⇒ Types::StartAutomationEventResponse
Initiates a one-time, on-demand automation for the specified recommended action.
<note markdown=“1”> Management accounts and delegated administrators can only initiate recommended actions for associated member accounts. You can associate a member account using ‘AssociateAccounts`.
</note>
1842 1843 1844 1845 |
# File 'lib/aws-sdk-computeoptimizerautomation/client.rb', line 1842 def start_automation_event(params = {}, = {}) req = build_request(:start_automation_event, params) req.send_request() end |
#tag_resource(params = {}) ⇒ Struct
Adds tags to the specified resource.
1887 1888 1889 1890 |
# File 'lib/aws-sdk-computeoptimizerautomation/client.rb', line 1887 def tag_resource(params = {}, = {}) req = build_request(:tag_resource, params) req.send_request() end |
#untag_resource(params = {}) ⇒ Struct
Removes tags from the specified resource.
1927 1928 1929 1930 |
# File 'lib/aws-sdk-computeoptimizerautomation/client.rb', line 1927 def untag_resource(params = {}, = {}) req = build_request(:untag_resource, params) req.send_request() end |
#update_automation_rule(params = {}) ⇒ Types::UpdateAutomationRuleResponse
Updates an existing automation rule.
2134 2135 2136 2137 |
# File 'lib/aws-sdk-computeoptimizerautomation/client.rb', line 2134 def update_automation_rule(params = {}, = {}) req = build_request(:update_automation_rule, params) req.send_request() end |
#update_enrollment_configuration(params = {}) ⇒ Types::UpdateEnrollmentConfigurationResponse
Updates your account’s Compute Optimizer Automation enrollment configuration.
2194 2195 2196 2197 |
# File 'lib/aws-sdk-computeoptimizerautomation/client.rb', line 2194 def update_enrollment_configuration(params = {}, = {}) req = build_request(:update_enrollment_configuration, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2223 2224 2225 |
# File 'lib/aws-sdk-computeoptimizerautomation/client.rb', line 2223 def waiter_names [] end |