Class: Aws::ComputeOptimizerAutomation::Types::Schedule
- Inherits:
-
Struct
- Object
- Struct
- Aws::ComputeOptimizerAutomation::Types::Schedule
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-computeoptimizerautomation/types.rb
Overview
Configuration for scheduling when automation rules should execute, including timing and execution windows.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#execution_window_in_minutes ⇒ Integer
The time window in minutes during which the automation rule can start implementing recommended actions.
-
#schedule_expression ⇒ String
The expression that defines when the schedule runs.
-
#schedule_expression_timezone ⇒ String
The timezone to use when interpreting the schedule expression.
Instance Attribute Details
#execution_window_in_minutes ⇒ Integer
The time window in minutes during which the automation rule can start implementing recommended actions.
2055 2056 2057 2058 2059 2060 2061 |
# File 'lib/aws-sdk-computeoptimizerautomation/types.rb', line 2055 class Schedule < Struct.new( :schedule_expression, :schedule_expression_timezone, :execution_window_in_minutes) SENSITIVE = [] include Aws::Structure end |
#schedule_expression ⇒ String
The expression that defines when the schedule runs. ‘cron` expression is supported. A `cron` expression consists of six fields separated by white spaces: (`minutes` `hours` `day_of_month` `month` `day_of_week` `year`)
<note markdown=“1”> You can schedule rules to run at most once per day. Your cron expression must use specific values (not wildcards) for the minutes and hours fields. For example: (‘30 12 * * *`) runs daily at 12:30 PM UTC.
</note>
2055 2056 2057 2058 2059 2060 2061 |
# File 'lib/aws-sdk-computeoptimizerautomation/types.rb', line 2055 class Schedule < Struct.new( :schedule_expression, :schedule_expression_timezone, :execution_window_in_minutes) SENSITIVE = [] include Aws::Structure end |
#schedule_expression_timezone ⇒ String
The timezone to use when interpreting the schedule expression.
2055 2056 2057 2058 2059 2060 2061 |
# File 'lib/aws-sdk-computeoptimizerautomation/types.rb', line 2055 class Schedule < Struct.new( :schedule_expression, :schedule_expression_timezone, :execution_window_in_minutes) SENSITIVE = [] include Aws::Structure end |